Skip to contents

AHMD sample Data object generated by the ReadAHMD() function.

Usage

AHMD_sample

Format

A list of class ReadAHMD with the following components:

input

A list with the arguments used in the call to ReadAHMD.

data

A data.frame with the columns country, Year, Age, Female, Male and Total.

download.date

A character string with the date of the download.

years

An integer vector with the years covered by the sample.

ages

A character vector with the ages covered by the sample.