Skip to contents

CHMD sample Data object generated by the ReadCHMD() function.

Usage

CHMD_sample

Format

A list of class ReadCHMD with the following components:

input

A list with the arguments used in the call to ReadCHMD.

data

A data.frame with the columns country, Year, Age, Female, Male and Total.

download.date

A character string with the date of the download.

years

An integer vector with the years covered by the sample.

ages

A character vector with the ages covered by the sample.