Skip to contents

HMD sample Data object generated by the ReadHMD() function.

Usage

HMD_sample

Format

A list of class ReadHMD with the following components:

input

A list with the arguments used in the call to ReadHMD.

data

A data.frame with the columns country, Year, Age, Female, Male and Total.

download.date

A character string with the date of the download.

years

An integer vector with the years covered by the sample.

ages

An integer vector with the ages covered by the sample.