Skip to contents

The Heligman-Pollard eight-parameter law of the whole lifespan, fitted on the odds of dying \(q_x/p_x\); the fitted quantity is a death probability.

Usage

HP(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

HP(x = 0:100)
#> $hx
#>   [1] 0.0075378214 0.0005534810 0.0003840906 0.0003149531 0.0002780111
#>   [6] 0.0002563053 0.0002434207 0.0002366777 0.0002368161 0.0002513477
#>  [11] 0.0002969030 0.0003930005 0.0005478174 0.0007474877 0.0009586315
#>  [16] 0.0011420511 0.0012677610 0.0013232657 0.0013133308 0.0012542462
#>  [21] 0.0011667071 0.0010701712 0.0009797202 0.0009051676 0.0008516152
#>  [26] 0.0008206581 0.0008116774 0.0008229207 0.0008522732 0.0008977366
#>  [31] 0.0009576799 0.0010309378 0.0011168182 0.0012150637 0.0013257964
#>  [36] 0.0014494631 0.0015867879 0.0017387360 0.0019064892 0.0020914305
#>  [41] 0.0022951379 0.0025193848 0.0027661460 0.0030376078 0.0033361828
#>  [46] 0.0036645268 0.0040255594 0.0044224869 0.0048588279 0.0053384412
#>  [51] 0.0058655573 0.0064448109 0.0070812780 0.0077805150 0.0085486006
#>  [56] 0.0093921813 0.0103185203 0.0113355485 0.0124519205 0.0136770717
#>  [61] 0.0150212803 0.0164957312 0.0181125821 0.0198850327 0.0218273940
#>  [66] 0.0239551594 0.0262850744 0.0288352047 0.0316250009 0.0346753577
#>  [71] 0.0380086651 0.0416488483 0.0456213942 0.0499533591 0.0546733540
#>  [76] 0.0598115021 0.0653993631 0.0714698183 0.0780569091 0.0851956238
#>  [81] 0.0929216239 0.1012709059 0.1102793893 0.1199824293 0.1304142493
#>  [86] 0.1416072921 0.1535914933 0.1663934818 0.1800357171 0.1945355811
#>  [91] 0.2099044427 0.2261467232 0.2432589943 0.2612291462 0.2800356645
#>  [96] 0.2996470605 0.3200214964 0.3411066431 0.3628398055 0.3851483364
#> [101] 0.4079503538
#> 
#> $par
#>       A       B       C       D       E      F_       G       H 
#> 5.0e-04 4.0e-03 8.0e-02 1.0e-03 1.0e+01 1.7e+01 5.0e-05 1.1e+00 
#>