The Heligman-Pollard law with an extra parameter in the old-age term, making it a full logistic that bends at the oldest ages.
Examples
HP3(x = 0:100)
#> $hx
#> [1] 0.0075950692 0.0005537845 0.0003842346 0.0003150479 0.0002780830
#> [6] 0.0002563645 0.0002434721 0.0002367243 0.0002368607 0.0002513970
#> [11] 0.0002969743 0.0003931346 0.0005480931 0.0007480171 0.0009595153
#> [16] 0.0011433133 0.0012693175 0.0013249552 0.0013149807 0.0012557278
#> [21] 0.0011679568 0.0010711808 0.0009805154 0.0009057873 0.0008520986
#> [26] 0.0008210388 0.0008119819 0.0008231690 0.0008524807 0.0008979147
#> [31] 0.0009578374 0.0010310815 0.0011169536 0.0012151949 0.0013259269
#> [36] 0.0014495955 0.0015869245 0.0017388787 0.0019066396 0.0020915902
#> [41] 0.0022953082 0.0025195671 0.0027663416 0.0030378180 0.0033364091
#> [46] 0.0036647706 0.0040258223 0.0044227706 0.0048591341 0.0053387719
#> [51] 0.0058659145 0.0064451969 0.0070816954 0.0077809662 0.0085490886
#> [56] 0.0093927091 0.0103190913 0.0113361663 0.0124525890 0.0136777951
#> [61] 0.0150220632 0.0164965784 0.0181134990 0.0198860249 0.0218284678
#> [66] 0.0239563213 0.0262863314 0.0288365644 0.0316264715 0.0346769478
#> [71] 0.0380103839 0.0416507056 0.0456234004 0.0499555252 0.0546756917
#> [76] 0.0598140236 0.0654020812 0.0714727463 0.0780600609 0.0851990136
#> [81] 0.0929252665 0.1012748163 0.1102835826 0.1199869208 0.1304190541
#> [86] 0.1416124252 0.1535969691 0.1663993140 0.1800419186 0.1945421637
#> [91] 0.2099114167 0.2261540972 0.2432667753 0.2612373388 0.2800442710
#> [96] 0.2996560809 0.3200309278 0.3411164801 0.3628500396 0.3851589567
#> [101] 0.4079613466
#>
#> $par
#> A B C D E F_ G H K
#> 5.0e-04 4.0e-03 8.0e-02 1.0e-03 1.0e+01 1.7e+01 5.0e-05 1.1e+00 1.0e+00
#>