Skip to contents

JMD sample Data object generated by the ReadJMD() function.

Usage

JMD_sample

Format

A list of class ReadJMD with the following components:

input

A list with the arguments used in the call to ReadJMD.

data

A data.frame with the columns region, Year, Age, Female, Male and Total.

download.date

A character string with the date of the download.

years

An integer vector with the years covered by the sample.

ages

A character vector with the ages covered by the sample.