Skip to contents

Dataset containing altered death rates (mx), death counts (Dx) and exposures (Ex) for the female population living in England & Wales in four different years: 1850, 1900, 1950 and 2010. This dataset is provided for testing purposes only. Download the actual data free of charge from https://www.mortality.org. Once a username and a password are created on the website, the function ReadHMD can be used for downloading.

Usage

ahmd

Format

A list with the components mx, Dx and Ex. Each component is a data.frame with 111 rows (ages 0 to 110) and one column per year: 1850, 1900, 1950 and 2010.

See also

Examples

head(ahmd$mx)
#>       1850     1900     1950     2010
#> 0 0.141755 0.151306 0.025785 0.004114
#> 1 0.058617 0.047934 0.002246 0.000313
#> 2 0.031200 0.019129 0.001204 0.000127
#> 3 0.021731 0.013033 0.000992 0.000138
#> 4 0.016886 0.009372 0.000692 0.000102
#> 5 0.012800 0.006678 0.000660 0.000082