Skip to contents

The Beard logistic hazard plus a constant, covering the age-independent component and the old-age levelling-off.

Usage

beard_makeham(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

beard_makeham(x = 0:100)
#> $hx
#>   [1] 0.01199601 0.01227248 0.01258715 0.01294526 0.01335278 0.01381646
#>   [7] 0.01434399 0.01494408 0.01562660 0.01640273 0.01728513 0.01828813
#>  [13] 0.01942791 0.02072274 0.02219321 0.02386250 0.02575669 0.02790500
#>  [19] 0.03034016 0.03309873 0.03622140 0.03975336 0.04374459 0.04825011
#>  [25] 0.05333021 0.05905062 0.06548242 0.07270199 0.08079059 0.08983374
#>  [31] 0.09992033 0.11114123 0.12358759 0.13734858 0.15250869 0.16914438
#>  [37] 0.18732047 0.20708589 0.22846944 0.25147531 0.27607901 0.30222378
#>  [43] 0.32981805 0.35873414 0.38880862 0.41984453 0.45161552 0.48387180
#>  [49] 0.51634763 0.54876999 0.58086762 0.61238005 0.64306582 0.67270944
#>  [55] 0.70112668 0.72816790 0.75371960 0.77770401 0.80007738 0.82082687
#>  [61] 0.83996679 0.85753433 0.87358515 0.88818908 0.90142614 0.91338300
#>  [67] 0.92414991 0.93381814 0.94247799 0.95021714 0.95711956 0.96326466
#>  [73] 0.96872677 0.97357489 0.97787262 0.98167817 0.98504457 0.98801989
#>  [79] 0.99064751 0.99296648 0.99501182 0.99681486 0.99840355 0.99980279
#>  [85] 1.00103473 1.00211903 1.00307310 1.00391238 1.00465052 1.00529958
#>  [91] 1.00587022 1.00637183 1.00681271 1.00720017 1.00754064 1.00783980
#>  [97] 1.00810264 1.00833355 1.00853640 1.00871459 1.00887111
#> 
#> $par
#>     A     B     C     K 
#> 0.002 0.130 0.010 1.000 
#>