Learn R Programming

MortalityLaws (version 2.2.0)

bring_parameters: Bring or Rename Starting Parameters in the Law Functions

Description

Bring or Rename Starting Parameters in the Law Functions

Usage

bring_parameters(law, par = NULL)

Value

Vector or initial model parameters

Arguments

law

The name of the mortality law to be used (e.g., "gompertz", "makeham"). Run availableLaws to see all options.

par

parameters of the selected model. If NULL the default values will be assigned automatically.