Skip to contents

A mixture law: Weibull + inverse-Weibull + Gompertz components combined on the survivorship, with the mixture weights normalised to the simplex.

Usage

carriere1(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

carriere1(x = 0:100)
#> $hx
#>   [1] 0.0000000000 0.0029532776 0.0009700148 0.0006143047 0.0004426643
#>   [6] 0.0003436712 0.0002803362 0.0002370502 0.0002061426 0.0001834306
#>  [11] 0.0001664550 0.0001536866 0.0001441340 0.0001371345 0.0001322358
#>  [16] 0.0001291267 0.0001275932 0.0001274918 0.0001287317 0.0001312624
#>  [21] 0.0001350664 0.0001401537 0.0001465582 0.0001543357 0.0001635625
#>  [26] 0.0001743353 0.0001867705 0.0002010055 0.0002171993 0.0002355338
#>  [31] 0.0002562156 0.0002794780 0.0003055835 0.0003348264 0.0003675360
#>  [36] 0.0004040803 0.0004448698 0.0004903623 0.0005410674 0.0005975527
#>  [41] 0.0006604499 0.0007304614 0.0008083689 0.0008950411 0.0009914440
#>  [46] 0.0010986514 0.0012178567 0.0013503864 0.0014977144 0.0016614787
#>  [51] 0.0018434995 0.0020457993 0.0022706253 0.0025204743 0.0027981204
#>  [56] 0.0031066459 0.0034494752 0.0038304130 0.0042536860 0.0047239903
#>  [61] 0.0052465430 0.0058271399 0.0064722201 0.0071889367 0.0079852362
#>  [66] 0.0088699463 0.0098528735 0.0109449111 0.0121581599 0.0135060611
#>  [71] 0.0150035450 0.0166671945 0.0185154283 0.0205687020 0.0228497329
#>  [76] 0.0253837477 0.0281987575 0.0313258614 0.0347995828 0.0386582395
#>  [81] 0.0429443521 0.0477050923 0.0529927736 0.0588653855 0.0653871723
#>  [86] 0.0726292516 0.0806702667 0.0895970579 0.0995053233 0.1105002225
#>  [91] 0.1226968346 0.1362203218 0.1512055380 0.1677956230 0.1861387615
#>  [96] 0.2063816249 0.2286567557 0.2530587676 0.2795996090 0.3081242224
#> [101] 0.3381511091
#> 
#> $par
#>     P1 sigma1     M1     P2 sigma2     M2 sigma3     M3 
#>  0.003 15.000  2.700  0.007  6.000  3.000  9.500 88.000 
#>