Skip to contents

A mixture law: Weibull + inverse-Gompertz + Gompertz components combined on the survivorship, with the mixture weights normalised to the simplex.

Usage

carriere2(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

carriere2(x = 0:100)
#> $hx
#>   [1] 0.0000000000 0.0064793743 0.0014160397 0.0008515567 0.0006320972
#>   [6] 0.0005324947 0.0004903805 0.0004818816 0.0004963391 0.0005286979
#>  [11] 0.0005766651 0.0006394918 0.0007174042 0.0008113244 0.0009227352
#>  [16] 0.0010536228 0.0012064646 0.0013842481 0.0015905114 0.0018294025
#>  [21] 0.0021057548 0.0024251799 0.0027941781 0.0032202677 0.0037121363
#>  [26] 0.0042798154 0.0049348839 0.0056907016 0.0065626795 0.0075685914
#>  [31] 0.0087289333 0.0100673450 0.0116111179 0.0133918388 0.0154462224
#>  [36] 0.0178171390 0.0205547428 0.0237175167 0.0273730957 0.0315989046
#>  [41] 0.0364828567 0.0421244458 0.0486364825 0.0561475456 0.0648050465
#>  [46] 0.0747787220 0.0862643732 0.0994877175 0.1147082459 0.1322229342
#>  [51] 0.1523694797 0.1755283372 0.2021220130 0.2326084300 0.2674617437
#>  [56] 0.3071266181 0.3519157170 0.4017837621 0.4558309105 0.5112241308
#>  [61] 0.5609898492 0.5903621632 0.5747755464 0.4928738951 0.3624979428
#>  [66] 0.2438390428 0.1751446143 0.1476786206 0.1398592710 0.1385382948
#>  [71] 0.1387503330 0.1391756999 0.1395694145 0.1399057038 0.1401886013
#>  [76] 0.1404240322 0.1406172250 0.1407726473 0.1408940864 0.1409847252
#>  [81] 0.1410472079 0.1410836974 0.1410959241 0.1410852285 0.1410525964
#>  [86] 0.1409986893 0.1409238692 0.1408282192 0.1407115600 0.1405734633
#>  [91] 0.1404132618 0.1402300567 0.1400227230 0.1397899134 0.1395300600
#>  [96] 0.1392413761 0.1389218561 0.1385692770 0.1381811983 0.1377549651
#> [101] 0.1372877107
#> 
#> $par
#>     P1 sigma1     M1     P2 sigma2     M2 sigma3     M3 
#>   0.01   2.00   1.00   0.01   7.00  49.00   7.00  49.00 
#>