Learn R Programming

MortalityLaws (version 2.2.0)

compute.ax: Find ax indicator

Description

Find ax indicator

Usage

compute.ax(x, mx, qx)

Value

ax - the point in the age interval where 50

have already occurred

Arguments

x

Numeric vector of ages at the beginning of each age interval. For a full life table, use single-year ages (e.g., 0:110). For an abridged life table, use the lower bound of each interval (e.g., c(0, 1, 5, 10, ..., 110)).

mx

Age-specific death rate in the age interval [x, x+n). Defined as Dx / Ex.

qx

Probability of dying within the age interval [x, x+n).