Skip to contents

The exponential rise of mortality with age, the classic adult and old-age law. The hazard is unbounded, so fit it over the adult ages.

Usage

gompertz(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

gompertz(x = 45:90)
#> $hx
#>  [1]  0.06944688  0.07908807  0.09006774  0.10257170  0.11681157  0.13302833
#>  [7]  0.15149643  0.17252844  0.19648028  0.22375732  0.25482119  0.29019761
#> [13]  0.33048527  0.37636601  0.42861629  0.48812040  0.55588536  0.63305803
#> [19]  0.72094445  0.82103200  0.93501455  1.06482111  1.21264850  1.38099853
#> [25]  1.57272032  1.79105854  2.03970830  2.32287771  2.64535907  3.01260999
#> [31]  3.43084576  3.90714453  4.44956709  5.06729330  5.77077743  6.57192513
#> [37]  7.48429488  8.52332743  9.70660720 11.05415979 12.58879092 14.33647241
#> [43] 16.32678170 18.59340241 21.17469441 24.11434300
#> 
#> $par
#>      A      B 
#> 0.0002 0.1300 
#> 
#> $Sx
#>  [1] 5.870365e-01 5.450753e-01 5.009293e-01 4.549924e-01 4.077863e-01
#>  [6] 3.599622e-01 3.122913e-01 2.656426e-01 2.209435e-01 1.791249e-01
#> [11] 1.410523e-01 1.074477e-01 7.881469e-02 5.537735e-02 3.704915e-02
#> [16] 2.344182e-02 1.391897e-02 7.687661e-03 3.910117e-03 1.810608e-03
#> [21] 7.534250e-04 2.775823e-04 8.903091e-05 2.438537e-05 5.580065e-06
#> [26] 1.040473e-06 1.536597e-07 1.740077e-08 1.456285e-09 8.636967e-11
#> [31] 3.460587e-12 8.870861e-14 1.367352e-15 1.180934e-17 5.273238e-20
#> [36] 1.110866e-22 9.946809e-26 3.361707e-29 3.745808e-33 1.179615e-37
#> [41] 8.809619e-43 1.277706e-48 2.866495e-55 7.676985e-63 1.827256e-71
#> [46] 2.762082e-81
#>