Skip to contents

The generalised Gompertz-Makeham formula without the Makeham constant: a Gompertz whose log hazard is quadratic, \(\mu_x = K \exp(B_1 x - B_2 x^2)\). It is the \(GM(0, 3)\) member of the family and the log-quadratic law used to test for deceleration in old age; prefer it when background mortality is negligible and the constant of makeham_logquad is not wanted. SIGN IS A CHOICE, as in makeham_logquad: only the decelerating branch is reachable.

Usage

gompertz_logquad(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

gompertz_logquad(x = 0:100)
#> $hx
#>   [1] 0.001000000 0.001104066 0.001216527 0.001337765 0.001468145 0.001608014
#>   [7] 0.001757689 0.001917457 0.002087569 0.002268230 0.002459603 0.002661793
#>  [13] 0.002874849 0.003098754 0.003333424 0.003578701 0.003834350 0.004100053
#>  [19] 0.004375409 0.004659928 0.004953032 0.005254054 0.005562235 0.005876727
#>  [25] 0.006196595 0.006520819 0.006848297 0.007177851 0.007508232 0.007838128
#>  [31] 0.008166170 0.008490942 0.008810992 0.009124837 0.009430980 0.009727919
#>  [37] 0.010014159 0.010288225 0.010548672 0.010794103 0.011023176 0.011234619
#>  [43] 0.011427240 0.011599941 0.011751725 0.011881707 0.011989125 0.012073343
#>  [49] 0.012133861 0.012170318 0.012182494 0.012170318 0.012133861 0.012073343
#>  [55] 0.011989125 0.011881707 0.011751725 0.011599941 0.011427240 0.011234619
#>  [61] 0.011023176 0.010794103 0.010548672 0.010288225 0.010014159 0.009727919
#>  [67] 0.009430980 0.009124837 0.008810992 0.008490942 0.008166170 0.007838128
#>  [73] 0.007508232 0.007177851 0.006848297 0.006520819 0.006196595 0.005876727
#>  [79] 0.005562235 0.005254054 0.004953032 0.004659928 0.004375409 0.004100053
#>  [85] 0.003834350 0.003578701 0.003333424 0.003098754 0.002874849 0.002661793
#>  [91] 0.002459603 0.002268230 0.002087569 0.001917457 0.001757689 0.001608014
#>  [97] 0.001468145 0.001337765 0.001216527 0.001104066 0.001000000
#> 
#> $par
#>     K    B1    B2 
#> 0.001 0.100 0.001 
#>