Skip to contents

The inverse-Gompertz hazard, which falls with age; it describes the decline of mortality after the infant peak.

Usage

invgompertz(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

invgompertz(x = 15:25)
#> $hx
#>  [1] 1.264487e-35 2.638492e-31 1.613842e-27 3.359978e-24 2.715087e-21
#>  [6] 9.555697e-19 1.620820e-16 1.448136e-14 7.368727e-13 2.286971e-11
#> [11] 4.597949e-10
#> 
#> $par
#> sigma     M 
#>   7.7  49.0 
#> 
#> $Sx
#>  [1] 1 1 1 1 1 1 1 1 1 1 1
#>