Skip to contents

The inverse-Weibull hazard; useful for childhood and the teenage years, where the logarithm of the hazard is concave.

Usage

invweibull(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

invweibull(x = 1:20)
#> $hx
#>  [1] 0.13379263 0.10239242 0.08161344 0.06788027 0.05819767 0.05100527
#>  [7] 0.04544642 0.04101650 0.03739973 0.03438851 0.03184068 0.02965562
#> [13] 0.02776003 0.02609925 0.02463165 0.02332495 0.02215375 0.02109774
#> [19] 0.02014052 0.01926868
#> 
#> $par
#> sigma     M 
#>    10     5 
#> 
#> $Sx
#>  [1] 0.8931221 0.7942593 0.7250028 0.6730781 0.6321206 0.5986297 0.5705089
#>  [8] 0.5464136 0.5254347 0.5069313 0.4904360 0.4755983 0.4621490 0.4498775
#> [15] 0.4386161 0.4282292 0.4186057 0.4096539 0.4012967 0.3934693
#>