The Kannisto logistic hazard, which rises like Gompertz and levels off at a
ceiling of one; the field standard for closing a life table at old age (see
the close and omega arguments of LifeTable).
Examples
kannisto(x = 85:120)
#> $hx
#> [1] 0.9999682 0.9999721 0.9999755 0.9999785 0.9999811 0.9999834 0.9999854
#> [8] 0.9999872 0.9999888 0.9999901 0.9999913 0.9999924 0.9999933 0.9999941
#> [15] 0.9999949 0.9999955 0.9999960 0.9999965 0.9999969 0.9999973 0.9999976
#> [22] 0.9999979 0.9999982 0.9999984 0.9999986 0.9999988 0.9999989 0.9999991
#> [29] 0.9999992 0.9999993 0.9999994 0.9999994 0.9999995 0.9999996 0.9999996
#> [36] 0.9999997
#>
#> $par
#> A B
#> 0.50 0.13
#>
#> $Sx
#> [1] 5.688875e-34 2.092882e-34 7.699486e-35 2.832548e-35 1.042057e-35
#> [6] 3.833582e-36 1.410318e-36 5.188340e-37 1.908707e-37 7.021813e-38
#> [11] 2.583204e-38 9.503155e-39 3.496040e-39 1.286129e-39 4.731432e-40
#> [16] 1.740605e-40 6.403355e-41 2.355671e-41 8.666059e-42 3.188074e-42
#> [21] 1.172830e-42 4.314609e-43 1.587259e-43 5.839210e-44 2.148129e-44
#> [26] 7.902534e-45 2.907183e-45 1.069494e-45 3.934452e-46 1.447405e-46
#> [31] 5.324710e-47 1.958852e-47 7.206219e-48 2.651021e-48 9.752565e-49
#> [36] 3.587770e-49
#>