Skip to contents

A nine-parameter Heligman-Pollard variant whose accident-hump term has two dispersion parameters, one either side of a cut age, so the hump can be asymmetric.

Usage

kostaki(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

kostaki(x = 0:100)
#> $hx
#>   [1] 0.0082454580 0.0005509271 0.0003489664 0.0002727368 0.0002342760
#>   [6] 0.0002128451 0.0002008810 0.0001949624 0.0001933386 0.0001950947
#>  [11] 0.0001999665 0.0002086224 0.0002232499 0.0002479931 0.0002886344
#>  [16] 0.0003512418 0.0004401446 0.0005560710 0.0006952489 0.0008498131
#>  [21] 0.0010093083 0.0011627193 0.0013004027 0.0014154691 0.0015044301
#>  [26] 0.0015671552 0.0016200192 0.0016783296 0.0017426191 0.0018134744
#>  [31] 0.0018915418 0.0019775327 0.0020722298 0.0021764941 0.0022912726
#>  [36] 0.0024176066 0.0025566406 0.0027096329 0.0028779661 0.0030631595
#>  [41] 0.0032668823 0.0034909677 0.0037374290 0.0040084771 0.0043065386
#>  [46] 0.0046342772 0.0049946153 0.0053907588 0.0058262235 0.0063048639
#>  [51] 0.0068309039 0.0074089713 0.0080441335 0.0087419370 0.0095084498
#>  [56] 0.0103503066 0.0112747574 0.0122897188 0.0134038296 0.0146265083
#>  [61] 0.0159680144 0.0174395127 0.0190531392 0.0208220699 0.0227605907
#>  [66] 0.0248841679 0.0272095176 0.0297546747 0.0325390567 0.0355835233
#>  [71] 0.0389104276 0.0425436561 0.0465086554 0.0508324397 0.0555435771
#>  [76] 0.0606721468 0.0662496642 0.0723089663 0.0788840512 0.0860098652
#>  [81] 0.0937220308 0.1020565083 0.1110491863 0.1207353947 0.1311493389
#>  [86] 0.1423234527 0.1542876729 0.1670686409 0.1806888422 0.1951656990
#>  [91] 0.2105106356 0.2267281451 0.2438148874 0.2617588571 0.2805386598
#>  [96] 0.3001229418 0.3204700123 0.3415276999 0.3632334739 0.3855148558
#> [101] 0.4082901319
#> 
#> $par
#>       A       B       C       D      E1      E2      F_       G       H 
#> 5.0e-04 1.0e-02 1.0e-01 1.0e-03 3.0e+00 1.0e-01 2.5e+01 5.0e-05 1.1e+00 
#>