Skip to contents

The Makeham hazard with the exponential term in mode/dispersion form, \(\mu_x = (1/\sigma) \exp((x - M)/\sigma) + C\).

Usage

makeham0(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

makeham0(x = 45:90)
#> $hx
#>  [1]  0.07828767  0.08901739  0.10123670  0.11515240  0.13099999  0.14904768
#>  [7]  0.16960090  0.19300749  0.21966358  0.25002029  0.28459137  0.32396190
#> [13]  0.36879818  0.41985901  0.47800852  0.54423084  0.61964670  0.70553242
#> [19]  0.80334151  0.91472928  1.04158083  1.18604298  1.35056057  1.53791788
#> [25]  1.75128569  1.99427502  2.27099815  2.58613831  2.94502887  3.35374362
#> [31]  3.81919958  4.34927403  4.95293786  5.64040735  6.42331712  7.31491699
#> [37]  8.33029622  9.48663890 10.80351475 12.30321035 14.01110625 15.95610657
#> [43] 18.17112813 20.69365753 23.56638560 26.83792985
#> 
#> $par
#>     sigma         M         C 
#>  7.692308 49.000000  0.001000 
#> 
#> $Sx
#>  [1] 5.284493e-01 4.860981e-01 4.420468e-01 3.967760e-01 3.508881e-01
#>  [6] 3.050998e-01 2.602226e-01 2.171279e-01 1.766976e-01 1.397600e-01
#> [11] 1.070178e-01 7.897608e-02 5.588246e-02 3.769302e-02 2.407493e-02
#> [16] 1.445107e-02 8.082058e-03 4.170296e-03 1.963266e-03 8.325853e-04
#> [21] 3.134859e-04 1.030802e-04 2.904909e-05 6.867341e-06 1.329079e-06
#> [26] 2.048120e-07 2.434808e-08 2.153938e-09 1.360954e-10 5.861448e-12
#> [31] 1.631584e-13 2.762747e-15 2.656017e-17 1.340135e-19 3.245089e-22
#> [36] 3.405655e-25 1.379309e-28 1.888871e-32 7.523940e-37 7.344083e-42
#> [41] 1.445072e-47 4.589235e-54 1.826097e-61 6.823507e-70 1.724143e-79
#> [46] 2.026764e-90
#>