Skip to contents

A generalisation of the Perks formula for old age, with an extra linear term that lets the hazard keep some exponential rise above the logistic plateau.

Usage

martinelle(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

martinelle(x = 0:100)
#> $hx
#>   [1] 2.818182e-03 3.058984e-03 3.330164e-03 3.635197e-03 3.977886e-03
#>   [6] 4.362380e-03 4.793203e-03 5.275281e-03 5.813980e-03 6.415152e-03
#>  [11] 7.085198e-03 7.831149e-03 8.660773e-03 9.582708e-03 1.060664e-02
#>  [16] 1.174349e-02 1.300571e-02 1.440755e-02 1.596541e-02 1.769825e-02
#>  [21] 1.962803e-02 2.178019e-02 2.418421e-02 2.687421e-02 2.988957e-02
#>  [26] 3.327569e-02 3.708481e-02 4.137684e-02 4.622042e-02 5.169404e-02
#>  [31] 5.788736e-02 6.490264e-02 7.285648e-02 8.188169e-02 9.212954e-02
#>  [36] 1.037723e-01 1.170059e-01 1.320536e-01 1.491693e-01 1.686423e-01
#>  [41] 1.908017e-01 2.160222e-01 2.447302e-01 2.774116e-01 3.146191e-01
#>  [46] 3.569824e-01 4.052184e-01 4.601432e-01 5.226864e-01 5.939063e-01
#>  [51] 6.750083e-01 7.673649e-01 8.725391e-01 9.923107e-01 1.128707e+00
#>  [56] 1.284036e+00 1.460926e+00 1.662372e+00 1.891782e+00 2.153040e+00
#>  [61] 2.450565e+00 2.789395e+00 3.175262e+00 3.614697e+00 4.115138e+00
#>  [66] 4.685054e+00 5.334089e+00 6.073228e+00 6.914980e+00 7.873590e+00
#>  [71] 8.965283e+00 1.020853e+01 1.162438e+01 1.323679e+01 1.507304e+01
#>  [76] 1.716422e+01 1.954572e+01 2.225783e+01 2.534646e+01 2.886388e+01
#>  [81] 3.286962e+01 3.743147e+01 4.262664e+01 4.854303e+01 5.528080e+01
#>  [86] 6.295395e+01 7.169236e+01 8.164391e+01 9.297701e+01 1.058835e+02
#>  [91] 1.205817e+02 1.373205e+02 1.563831e+02 1.780921e+02 2.028150e+02
#>  [96] 2.309700e+02 2.630339e+02 2.995490e+02 3.411335e+02 3.884912e+02
#> [101] 4.424234e+02
#> 
#> $par
#>     A     B     C     D     K 
#> 0.001 0.130 0.001 0.100 0.001 
#>