Skip to contents

The Gompertz hazard with a negative exponent, the hazard of a negative Gompertz distribution; proposed by Thiele for the risk of death prior to maturity, and reused by Siler.

Usage

neggompertz(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

neggompertz(x = 0:20)
#> $hx
#>  [1] 2.000000e-02 1.340640e-02 8.986579e-03 6.023884e-03 4.037930e-03
#>  [6] 2.706706e-03 1.814359e-03 1.216201e-03 8.152441e-04 5.464744e-04
#> [11] 3.663128e-04 2.455468e-04 1.645949e-04 1.103313e-04 7.395727e-05
#> [16] 4.957504e-05 3.323115e-05 2.227550e-05 1.493172e-05 1.000903e-05
#> [21] 6.709253e-06
#> 
#> $par
#>    A    B 
#> 0.02 0.40 
#>