Skip to contents

The hazard of a Pareto type II (Lomax) distribution, \(\mu_x = A / (x + C)\); a shifted power hazard with the exponent fixed at one.

Usage

pareto_2(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

pareto_2(x = 1:20)
#> $hx
#>  [1] 0.0099900100 0.0049975012 0.0033322226 0.0024993752 0.0019996001
#>  [6] 0.0016663889 0.0014283674 0.0012498438 0.0011109877 0.0009999000
#> [11] 0.0009090083 0.0008332639 0.0007691716 0.0007142347 0.0006666222
#> [16] 0.0006249609 0.0005882007 0.0005555247 0.0005262881 0.0004999750
#> 
#> $par
#>     A     C 
#> 0.010 0.001 
#>