Skip to contents

Prints the header of a CHMD download (web address, download date, data type, interval, year and age coverage, regions) followed by the first and the last rows of the data.

Usage

# S3 method for class 'ReadCHMD'
print(x, ...)

Arguments

x

An object of class "ReadCHMD".

...

Further arguments passed to or from other methods.

Value

The object x, invisibly. Called for its printed output.

See also