Prints the catalogue of mortality laws (year, name, model formula, type and code) followed by the legend that explains the type numbers.
Usage
# S3 method for class 'availableLaws'
print(x, ...)Prints the catalogue of mortality laws (year, name, model formula, type and code) followed by the legend that explains the type numbers.
# S3 method for class 'availableLaws'
print(x, ...)