Skip to contents

A plain quadratic hazard, \(\mu_x = A + Bx + Cx^2\); a smooth baseline over the adult ages that cannot level off at the oldest ages.

Usage

quadratic(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

quadratic(x = 0:100)
#> $hx
#>   [1]   0.01   1.02   2.05   3.10   4.17   5.26   6.37   7.50   8.65   9.82
#>  [11]  11.01  12.22  13.45  14.70  15.97  17.26  18.57  19.90  21.25  22.62
#>  [21]  24.01  25.42  26.85  28.30  29.77  31.26  32.77  34.30  35.85  37.42
#>  [31]  39.01  40.62  42.25  43.90  45.57  47.26  48.97  50.70  52.45  54.22
#>  [41]  56.01  57.82  59.65  61.50  63.37  65.26  67.17  69.10  71.05  73.02
#>  [51]  75.01  77.02  79.05  81.10  83.17  85.26  87.37  89.50  91.65  93.82
#>  [61]  96.01  98.22 100.45 102.70 104.97 107.26 109.57 111.90 114.25 116.62
#>  [71] 119.01 121.42 123.85 126.30 128.77 131.26 133.77 136.30 138.85 141.42
#>  [81] 144.01 146.62 149.25 151.90 154.57 157.26 159.97 162.70 165.45 168.22
#>  [91] 171.01 173.82 176.65 179.50 182.37 185.26 188.17 191.10 194.05 197.02
#> [101] 200.01
#> 
#> $par
#>    A    B    C 
#> 0.01 1.00 0.01 
#>