Skip to contents

The Scholey exponentially-truncated power hazard, \(\mu_x = A (x + C)^{-B} \exp(-Dx)\), the best-fitting parametric form on his day-level US infant data; it nests the negative Gompertz, Pareto II, shifted power and shifted Weibull hazards. AGE RESOLUTION MATTERS: D is identified only on day- or week-level data over the first year; on single years of age it collapses to the boundary and the fit reduces to scholey_shifted_power, in which case the engine warns.

Usage

scholey(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

scholey(x = seq(0, 1, by = 1/12))
#> $hx
#>  [1] 0.251188643 0.052162108 0.033094325 0.025041555 0.020441951 0.017411745
#>  [7] 0.015240042 0.013594306 0.012296590 0.011242384 0.010365955 0.009623725
#> [13] 0.008985569
#> 
#> $par
#>    A    B    C    D 
#> 0.01 0.70 0.01 0.10 
#>