Skip to contents

A three-term competing-risks hazard: a declining infancy term, a constant background term and a rising old-age term.

Usage

siler(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

siler(x = 0:100)
#> $hx
#>   [1] 0.002200000 0.002188704 0.002180551 0.002175182 0.002172280 0.002171568
#>   [7] 0.002172804 0.002175774 0.002180291 0.002186193 0.002193335 0.002201592
#>  [13] 0.002210853 0.002221024 0.002232019 0.002243766 0.002256199 0.002269264
#>  [19] 0.002282910 0.002297096 0.002311785 0.002326944 0.002342546 0.002358567
#>  [25] 0.002374986 0.002391785 0.002408950 0.002426467 0.002444325 0.002462515
#>  [31] 0.002481029 0.002499862 0.002519007 0.002538462 0.002558223 0.002578287
#>  [37] 0.002598653 0.002619321 0.002640289 0.002661559 0.002683131 0.002705006
#>  [43] 0.002727185 0.002749670 0.002772463 0.002795567 0.002818984 0.002842717
#>  [49] 0.002866769 0.002891142 0.002915842 0.002940869 0.002966230 0.002991926
#>  [55] 0.003017963 0.003044344 0.003071072 0.003098154 0.003125591 0.003153390
#>  [61] 0.003181554 0.003210088 0.003238997 0.003268286 0.003297959 0.003328021
#>  [67] 0.003358477 0.003389332 0.003420592 0.003452261 0.003484345 0.003516849
#>  [73] 0.003549779 0.003583140 0.003616938 0.003651179 0.003685868 0.003721010
#>  [79] 0.003756613 0.003792682 0.003829223 0.003866242 0.003903746 0.003941740
#>  [85] 0.003980232 0.004019228 0.004058733 0.004098756 0.004139303 0.004180380
#>  [91] 0.004221994 0.004264153 0.004306864 0.004350134 0.004393970 0.004438379
#>  [97] 0.004483370 0.004528949 0.004575125 0.004621905 0.004669297
#> 
#> $par
#>      A      B      C      D      E 
#> 0.0002 0.1300 0.0010 0.0010 0.0130 
#>