Skip to contents

The Perks hazard with an extra B*C^-x denominator term that peaks at birth and decays geometrically, so the hazard is dampened at young ages and converges to Perks at old ages. ATTRIBUTION IS UNVERIFIED: the citation to Steffensen (1930) is real, but whether the 1930 text contains this form is not (the scan is paywalled), so it is documented as attributed.

Usage

steffensen(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

steffensen(x = 0:100)
#> $hx
#>   [1] 0.01830357 0.01912730 0.01998421 0.02087527 0.02180143 0.02276363
#>   [7] 0.02376282 0.02479991 0.02587580 0.02699134 0.02814738 0.02934470
#>  [13] 0.03058406 0.03186616 0.03319163 0.03456107 0.03597499 0.03743382
#>  [19] 0.03893792 0.04048755 0.04208290 0.04372402 0.04541088 0.04714332
#>  [25] 0.04892108 0.05074376 0.05261084 0.05452164 0.05647538 0.05847111
#>  [31] 0.06050775 0.06258407 0.06469871 0.06685015 0.06903673 0.07125666
#>  [37] 0.07350800 0.07578870 0.07809656 0.08042928 0.08278444 0.08515953
#>  [43] 0.08755194 0.08995899 0.09237792 0.09480593 0.09724015 0.09967772
#>  [49] 0.10211572 0.10455127 0.10698148 0.10940347 0.11181444 0.11421160
#>  [55] 0.11659224 0.11895375 0.12129357 0.12360925 0.12589846 0.12815897
#>  [61] 0.13038868 0.13258561 0.13474794 0.13687396 0.13896210 0.14101097
#>  [67] 0.14301928 0.14498591 0.14690988 0.14879034 0.15062660 0.15241808
#>  [73] 0.15416436 0.15586511 0.15752016 0.15912943 0.16069296 0.16221089
#>  [79] 0.16368345 0.16511098 0.16649390 0.16783268 0.16912789 0.17038016
#>  [85] 0.17159018 0.17275867 0.17388642 0.17497424 0.17602301 0.17703359
#>  [91] 0.17800691 0.17894389 0.17984547 0.18071261 0.18154627 0.18234742
#>  [97] 0.18311702 0.18385605 0.18456545 0.18524618 0.18589919
#> 
#> $par
#>      A      B      C      D 
#> 0.0005 0.0200 1.0500 0.1000 
#>