Learn R Programming

MortalityLaws (version 2.2.0)

uxAbove100: Educate mx or qx on how to behave above age 100 if it gets in trouble (with NA's, zero's and Inf)

Description

Educate mx or qx on how to behave above age 100 if it gets in trouble (with NA's, zero's and Inf)

Usage

uxAbove100(x, ux, omega = 100, verbose = FALSE)

Value

A vector of rates

Arguments

x

Numeric vector of ages at the beginning of each age interval. For a full life table, use single-year ages (e.g., 0:110). For an abridged life table, use the lower bound of each interval (e.g., c(0, 1, 5, 10, ..., 110)).

ux

A vector of mx or qx.

omega

Threshold age. Default: 100.

verbose

A logical value. Set verbose = FALSE to silent the process that take place inside the function and avoid progress messages.