Skip to contents

A quadratic hazard with a reciprocal closing term, \(\mu_x = A + Bx + Cx^2 + I/(N - x)\), so the table can close at a finite age \(N\).

Usage

vandermaen(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

vandermaen(x = 0:100)
#> $hx
#>   [1]   0.510000   1.522513   2.555051   3.607614   4.680204   5.772821
#>   [7]   6.885464   8.018135   9.170833  10.343560  11.536316  12.749101
#>  [13]  13.981915  15.234759  16.507634  17.800541  19.113478  20.446448
#>  [19]  21.799451  23.172486  24.565556  25.978659  27.411798  28.864972
#>  [25]  30.338182  31.831429  33.344713  34.878035  36.431395  38.004795
#>  [31]  39.598235  41.211716  42.845238  44.498802  46.172410  47.866061
#>  [37]  49.579756  51.313497  53.067284  54.841118  56.635000  58.448931
#>  [43]  60.282911  62.136943  64.011026  65.905161  67.819351  69.753595
#>  [49]  71.707895  73.682252  75.676667  77.691141  79.725676  81.780272
#>  [55]  83.854932  85.949655  88.064444  90.199301  92.354225  94.529220
#>  [61]  96.724286  98.939424 101.174638 103.429927 105.705294 108.000741
#>  [67] 110.316269 112.651880 115.007576 117.383359 119.779231 122.195194
#>  [73] 124.631250 127.087402 129.563651 132.060000 134.576452 137.113008
#>  [79] 139.669672 142.246446 144.843333 147.460336 150.097458 152.754701
#>  [85] 155.432069 158.129565 160.847193 163.584956 166.342857 169.120901
#>  [91] 171.919091 174.737431 177.575926 180.434579 183.313396 186.212381
#>  [97] 189.131538 192.070874 195.030392 198.010099 201.010000
#> 
#> $par
#>     A     B     C     I     N 
#> 1e-02 1e+00 1e-02 1e+02 2e+02 
#>