Skip to contents

The linear form of the Van der Maen hazard with the same reciprocal closing term, \(\mu_x = A + Bx + I/(N - x)\).

Usage

vandermaen2(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

vandermaen2(x = 0:100)
#> $hx
#>   [1]   0.510000   1.512513   2.515051   3.517614   4.520204   5.522821
#>   [7]   6.525464   7.528135   8.530833   9.533560  10.536316  11.539101
#>  [13]  12.541915  13.544759  14.547634  15.550541  16.553478  17.556448
#>  [19]  18.559451  19.562486  20.565556  21.568659  22.571798  23.574972
#>  [25]  24.578182  25.581429  26.584713  27.588035  28.591395  29.594795
#>  [31]  30.598235  31.601716  32.605238  33.608802  34.612410  35.616061
#>  [37]  36.619756  37.623497  38.627284  39.631118  40.635000  41.638931
#>  [43]  42.642911  43.646943  44.651026  45.655161  46.659351  47.663595
#>  [49]  48.667895  49.672252  50.676667  51.681141  52.685676  53.690272
#>  [55]  54.694932  55.699655  56.704444  57.709301  58.714225  59.719220
#>  [61]  60.724286  61.729424  62.734638  63.739927  64.745294  65.750741
#>  [67]  66.756269  67.761880  68.767576  69.773359  70.779231  71.785194
#>  [73]  72.791250  73.797402  74.803651  75.810000  76.816452  77.823008
#>  [79]  78.829672  79.836446  80.843333  81.850336  82.857458  83.864701
#>  [85]  84.872069  85.879565  86.887193  87.894956  88.902857  89.910901
#>  [91]  90.919091  91.927431  92.935926  93.944579  94.953396  95.962381
#>  [97]  96.971538  97.980874  98.990392 100.000099 101.010000
#> 
#> $par
#>     A     B     I     N 
#> 1e-02 1e+00 1e+02 2e+02 
#>