Skip to contents

The Weibull hazard; increasing when \(\sigma < M\), non-increasing otherwise. NOT DEFINED AT BIRTH: the hazard is 0 when the shape is greater than one and unbounded when it is smaller, so age 0 is reported as missing and carries no weight in the fit; fit the law from age 1.

Usage

weibull(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

weibull(x = 1:20)
#> $hx
#>  [1] 0.5000000 0.3535534 0.2886751 0.2500000 0.2236068 0.2041241 0.1889822
#>  [8] 0.1767767 0.1666667 0.1581139 0.1507557 0.1443376 0.1386750 0.1336306
#> [15] 0.1290994 0.1250000 0.1212678 0.1178511 0.1147079 0.1118034
#> 
#> $par
#> sigma     M 
#>     2     1 
#> 
#> $Sx
#>  [1] 0.36787944 0.24311673 0.17692121 0.13533528 0.10687793 0.08633763
#>  [7] 0.07095203 0.05910575 0.04978707 0.04232922 0.03627506 0.03130111
#> [13] 0.02717246 0.02371477 0.02079623 0.01831564 0.01619414 0.01436960
#> [19] 0.01279247 0.01142289
#>