Skip to contents

A two-term law giving a death probability rather than a hazard, \(q_x = (1/B) A^{-(Bx)^N} + A^{-(M - x)^N}\), so it covers both ends of the lifespan.

Usage

wittstein(x, par = NULL)

Arguments

x

vector of age at the beginning of the age classes.

par

parameters of the selected model. If NULL the default values are assigned automatically.

Value

A list of rates and model parameters.

Examples

wittstein(x = 0:100)
#> $hx
#>   [1] 1.0173415 0.6843643 0.5816607 0.5138888 0.4632664 0.4230925 0.3900175
#>   [8] 0.3621004 0.3381066 0.3171987 0.2987808 0.2824133 0.2677624 0.2545684
#>  [15] 0.2426253 0.2317672 0.2218583 0.2127864 0.2044573 0.1967919 0.1897225
#>  [22] 0.1831913 0.1771483 0.1715501 0.1663589 0.1615414 0.1570686 0.1529145
#>  [29] 0.1490563 0.1454738 0.1421487 0.1390650 0.1362082 0.1335652 0.1311246
#>  [36] 0.1288760 0.1268099 0.1249182 0.1231933 0.1216285 0.1202181 0.1189566
#>  [43] 0.1178396 0.1168631 0.1160234 0.1153178 0.1147438 0.1142993 0.1139829
#>  [50] 0.1137935 0.1137305 0.1137935 0.1139829 0.1142993 0.1147438 0.1153178
#>  [57] 0.1160234 0.1168631 0.1178396 0.1189566 0.1202181 0.1216285 0.1231933
#>  [64] 0.1249182 0.1268099 0.1288760 0.1311246 0.1335652 0.1362082 0.1390650
#>  [71] 0.1421487 0.1454738 0.1490563 0.1529145 0.1570686 0.1615414 0.1663589
#>  [78] 0.1715501 0.1771483 0.1831913 0.1897225 0.1967919 0.2044573 0.2127864
#>  [85] 0.2218583 0.2317672 0.2426253 0.2545684 0.2677624 0.2824133 0.2987808
#>  [92] 0.3171987 0.3381066 0.3621004 0.3900175 0.4230925 0.4632664 0.5138888
#>  [99] 0.5816607 0.6843643 1.0173415
#> 
#> $par
#>     A     B     N     M 
#>   1.5   1.0   0.5 100.0 
#>