CHMD sample Data object generated by the ReadCHMD() function.
Source: R/MortalityLaws-data.R
CHMD_sample.RdCHMD sample
Data object generated by the ReadCHMD() function.
Format
A list of class ReadCHMD with the following components:
- input
A list with the arguments used in the call to
ReadCHMD.- data
A
data.framewith the columnscountry,Year,Age,Female,MaleandTotal.- download.date
A character string with the date of the download.
- years
An integer vector with the years covered by the sample.
- ages
A character vector with the ages covered by the sample.