HMD sample Data object generated by the ReadHMD() function.
Source: R/MortalityLaws-data.R
HMD_sample.RdHMD sample
Data object generated by the ReadHMD() function.
Format
A list of class ReadHMD with the following components:
- input
A list with the arguments used in the call to
ReadHMD.- data
A
data.framewith the columnscountry,Year,Age,Female,MaleandTotal.- download.date
A character string with the date of the download.
- years
An integer vector with the years covered by the sample.
- ages
An integer vector with the ages covered by the sample.