Download detailed mortality and population data for different provinces and territories in Australia, in a single object from the Australian Human Mortality Database.
Arguments
- what
What type of data are you looking for? The following options might be available for some or all the countries and regions:
"births"– birth records (the 1-year product only; HMD does not publish births by 5-year age group or by multi-year periods);"Dx_lexis"– deaths by Lexis triangles;"Ex_lexis"– exposure-to-risk by Lexis triangles;"population"– population size;"Dx"– death counts;"Ex"– exposure-to-risk;"mx"– central death-rates;"LT_f"– period life tables for females;"LT_m"– period life tables for males;"LT_t"– period life tables both sexes combined;"e0"– period life expectancy at birth;"Exc"– cohort exposures;"mxc"– cohort death-rates;"LT_fc"– cohort life tables for females;"LT_mc"– cohort life tables for males;"LT_tc"– cohort life tables both sexes combined;"e0c"– cohort life expectancy at birth;
- regions
Specify the region specific data you want to download by adding the AHMD region code/s. Options:
"ACT"– Australian Capital Territory;"NSW"– New South Wales;"NT"– Northern Territory;"QLD"– Queensland;"SA"– South Australia;"TAS"– Tasmania;"VIC"– Victoria;"WA"– Western Australia;NULL– ifNULLdata for all the regions are downloaded.
- interval
Datasets are given in various age and time formats based on which the records are aggregated. Interval options:
"1x1"– by age and year;"1x5"– by age and 5-year time interval;"1x10"– by age and 10-year time interval;"5x1"– by 5-year age group and year;"5x5"– by 5-year age group and 5-year time interval;"5x10"–by 5-year age group and 10-year time interval.
- save
Do you want to save a copy of the dataset on your local machine? Logical. Default:
FALSE.- show
Choose whether to display a progress bar. Logical. Default:
TRUE.
Value
A ReadAHMD object that contains:
- input
List with the input values;
- data
Data downloaded from AHMD;
- download.date
Time stamp;
- years
Numerical vector with the years covered in the data;
- ages
Numerical vector with ages covered in the data.
Details
The Australian Human Mortality Database is a "satellite" of the Human Mortality Database, built with the same methodology, so the two are directly comparable. It covers Australia, its states and its territories. See the AHMD website for its history and research team. The database is open, so no login is needed.
Examples
if (FALSE) { # \dontrun{
# Download demographic data for Australian Capital Territory and
# Tasmania regions in 5x1 format
# Death counts. We don't want to export data outside R.
AHMD_Dx <- ReadAHMD(what = "Dx",
regions = c('ACT', 'TAS'),
interval = "5x1",
save = FALSE)
AHMD_Dx
# Download life tables for female population in all the states and export data.
LTF <- ReadAHMD(what = "LT_f", interval = "5x1", save = FALSE)
LTF
} # }