availableHMD: Check Data Availability in HMD
Description
Returns information about the data available in the Human Mortality
Database (HMD), including the range of years covered by the life tables
for each country or region.
Usage
availableHMD(link = "https://www.mortality.org/Data/DataAvailability")
Arguments
- link
URL to the HMD available data.
Default: "https://www.mortality.org/Data/DataAvailability"