Learn R Programming

MortalityLaws (version 2.2.0)

availableLF: Check Available Loss Functions

Description

Returns information about the loss functions implemented for use with the optimisation procedure in the MortalityLaw function.

Usage

availableLF()

Arguments

Value

A list of class availableLF with the components:

table

Table with loss functions and codes to be used in MortalityLaw.

legend

Table with details about the abbreviation used.

Author

Marius D. Pascariu

See Also

MortalityLaw

Examples

Run this code
availableLF()

Run the code above in your browser using DataLab