powered by
Returns information about the loss functions implemented for use with the optimisation procedure in the MortalityLaw function.
MortalityLaw
availableLF()
A list of class availableLF with the components:
availableLF
Table with loss functions and codes to be used in MortalityLaw.
Table with details about the abbreviation used.
Marius D. Pascariu
Run the code above in your browser using DataLab