Find ax indicator
compute.ax(x, mx, qx)ax - the point in the age interval where 50
have already occurred
Numeric vector of ages at the beginning of each age interval.
For a full life table, use single-year ages (e.g., 0:110).
For an abridged life table, use the lower bound of each interval
(e.g., c(0, 1, 5, 10, ..., 110)).
Age-specific death rate in the age interval [x, x+n).
Defined as Dx / Ex.
Probability of dying within the age interval [x, x+n).