Function that identifies the case/problem we have to solve
find.my.case(Dx = NULL, Ex = NULL, mx = NULL, qx = NULL, lx = NULL, dx = NULL)A list containing problem solving details
Death counts. Each element represents the total number of
deaths during the calendar year to persons aged x to
x + n (where n is the length of the age interval).
Must be provided together with Ex.
Exposure-to-risk in the period. This is usually approximated
by the mid-year population aged x to x + n. Must be
provided together with Dx.
Age-specific death rate in the age interval [x, x+n).
Defined as Dx / Ex.
Probability of dying within the age interval [x, x+n).
Probability of surviving to exact age x (if lx0 = 1),
or the number of survivors at exact age x (if lx0 > 1).
When lx is the sole input, the values are re-scaled to the
chosen radix lx0.
Number of deaths in the life-table population occurring in
the age interval [x, x+n). When dx is the sole input,
the values are re-scaled to sum to lx0.