The Gompertz hazard in terms of its mode \(M\) and dispersion
\(\sigma\), \(\mu_x = (1/\sigma) \exp((x - M)/\sigma)\); the same curve
as gompertz with coefficients that read off the plot.
Examples
gompertz0(x = 45:90)
#> $hx
#> [1] 0.07725058 0.08796373 0.10016258 0.11405318 0.12987013 0.14788058
#> [7] 0.16838874 0.19174097 0.21833170 0.24861005 0.28308741 0.32234611
#> [13] 0.36704923 0.41795180 0.47591356 0.54191349 0.61706632 0.70264138
#> [19] 0.80008404 0.91104009 1.03738357 1.18124844 1.34506456 1.53159877
#> [25] 1.74400164 1.98586065 2.26126079 2.57485355 2.93193551 3.33853777
#> [31] 3.80152783 4.32872559 4.92903539 5.61259645 6.39095409 7.27725476
#> [37] 8.28646803 9.43563951 10.74417865 12.23418664 13.93082968 15.86276401
#> [43] 18.06261994 20.56755298 23.41987137 26.66775068
#>
#> $par
#> sigma M
#> 7.7 49.0
#>
#> $Sx
#> [1] 5.526080e-01 5.088522e-01 4.632313e-01 4.162429e-01 3.685139e-01
#> [6] 3.207936e-01 2.739334e-01 2.288514e-01 1.864801e-01 1.476997e-01
#> [11] 1.132622e-01 8.371459e-02 5.933500e-02 4.009491e-02 2.566027e-02
#> [16] 1.543665e-02 8.654399e-03 4.477835e-03 2.114527e-03 8.998472e-04
#> [21] 3.401478e-04 1.123502e-04 3.182450e-05 7.567957e-06 1.474650e-06
#> [26] 2.290320e-07 2.747512e-08 2.456203e-09 1.570934e-10 6.862030e-12
#> [31] 1.941702e-13 3.351180e-15 3.293982e-17 1.705481e-19 4.255655e-22
#> [36] 4.625057e-25 1.950922e-28 2.801127e-32 1.178934e-36 1.226881e-41
#> [41] 2.600839e-47 9.007299e-54 3.963947e-61 1.665186e-69 4.820781e-79
#> [46] 6.637273e-90
#>