Inverse-Gompertz Mortality Law - informative parameterization
Source:R/MortalityLaw_models.R
invgompertz.RdThe inverse-Gompertz hazard, which falls with age; it describes the decline of mortality after the infant peak.
R/MortalityLaw_models.R
invgompertz.RdThe inverse-Gompertz hazard, which falls with age; it describes the decline of mortality after the infant peak.