Function to convert mx into qx and back, using the constant force of mortality assumption (CFM).
mx_qx(x, nx, ux, out = c("qx", "mx"))A vector of rates
Numeric vector of ages at the beginning of each age interval.
For a full life table, use single-year ages (e.g., 0:110).
For an abridged life table, use the lower bound of each interval
(e.g., c(0, 1, 5, 10, ..., 110)).
Length of the age-intervals.
A vector of mx or qx.
Type of the output: mx or qx.