Prints a life table in a readable form: a header with the type (full or abridged), the number of tables and the age intervals, then the first and the last rows of every column, with the middle rows elided.
Usage
# S3 method for class 'LifeTable'
print(x, ...)