Prints the header of an AHMD download (web address, download date, data type, interval, year and age coverage, regions) followed by the first and the last rows of the data.
Usage
# S3 method for class 'ReadAHMD'
print(x, ...)Prints the header of an AHMD download (web address, download date, data type, interval, year and age coverage, regions) followed by the first and the last rows of the data.
# S3 method for class 'ReadAHMD'
print(x, ...)