Prints the table of loss functions and their codes, with the legend that explains the notation, followed by a short note on choosing between them.
Usage
# S3 method for class 'availableLF'
print(x, ...)Prints the table of loss functions and their codes, with the legend that explains the notation, followed by a short note on choosing between them.
# S3 method for class 'availableLF'
print(x, ...)