Educate mx or qx on how to behave above age 100 if it gets in trouble (with NA's, zero's and Inf)
uxAbove100(x, ux, omega = 100, verbose = FALSE)A vector of rates
Numeric vector of ages at the beginning of each age interval.
For a full life table, use single-year ages (e.g., 0:110).
For an abridged life table, use the lower bound of each interval
(e.g., c(0, 1, 5, 10, ..., 110)).
A vector of mx or qx.
Threshold age. Default: 100.
A logical value. Set verbose = FALSE to silent
the process that take place inside the function and avoid progress messages.